@@ -24,6 +24,7 @@ Authors:
 
 import numpy
 import functools
+import logging
 
 import networkx as nx
 
@@ -37,7 +38,7 @@ from mlxtend.evaluate import permutation_test
 from itertools import groupby, count
 
 from ..molecule import Hinge
-
+from ..utilities import WriteOBJ
 
 
 def predict_hinge(atoms, outputfile, Alpha=float('Inf'),method='AlphaShape',GenerateKirchoff=False,filename='Output.pdb',MinimumHingeLength=5,nclusters=4):
@@ -467,16 +468,12 @@ def hinge_cli(args,mol):
                 WriteOBJ(Backbone, SelectedTesselations, args.generateobj)
         else:
             for i in mol[0].get_chains():
-                Backbone = [item for sublist in mol[0][i.get_id()].get_backbone() for item in sublist]
-                SelectedTesselations = predict_hinge(Backbone, args.outputfile, Alpha=float(args.alpha), filename=args.filename,nclusters=args.e_clusters,MinimumHingeLength=args.minhnglen)
-        
-        if args.nodeid is not None:
-            urlopen(args.callbackurl + '/' + str(args.nodeid) + "/0")
+                try:
+                    Backbone = [item for sublist in mol[0][i.get_id()].get_backbone() for item in sublist]
+                    SelectedTesselations = predict_hinge(Backbone, args.outputfile, Alpha=float(args.alpha), filename=args.filename,nclusters=args.e_clusters,MinimumHingeLength=args.minhnglen)
+                except:
+                    logging.warning('Chain '+str(i.get_id())+' has none/missing backbone atoms to calculate the hinge.')
 
-    except Exception:
-        if args.nodeid is not None:
-            urlopen(args.callbackurl + '/' + str(args.nodeid) + "/1")
-    
     finally:
         print_footnotes(args.outputfile)
         args.outputfile.flush()
